@@ -90,17 +90,19 @@
 #' r2_nakagawa(model)
 #' r2_nakagawa(model, by_group = TRUE)
 #' @export
-r2_nakagawa <- function(model,
-                        by_group = FALSE,
-                        tolerance = 1e-8,
-                        ci = NULL,
-                        iterations = 100,
-                        ci_method = NULL,
-                        null_model = NULL,
-                        approximation = "lognormal",
-                        model_component = NULL,
-                        verbose = TRUE,
-                        ...) {
+r2_nakagawa <- function(
+  model,
+  by_group = FALSE,
+  tolerance = 1e-8,
+  ci = NULL,
+  iterations = 100,
+  ci_method = NULL,
+  null_model = NULL,
+  approximation = "lognormal",
+  model_component = NULL,
+  verbose = TRUE,
+  ...
+) {
   # calculate random effect variances
   vars <- .compute_random_vars(
     model,
@@ -123,11 +125,15 @@ r2_nakagawa <- function(model,
   if (isTRUE(by_group)) {
     # with random slopes, explained variance is inaccurate
     if (!is.null(insight::find_random_slopes(model)) && verbose) {
-      insight::format_warning("Model contains random slopes. Explained variance by levels is not accurate.")
+      insight::format_warning(
+        "Model contains random slopes. Explained variance by levels is not accurate."
+      )
     }
 
     if (!is.null(ci) && !is.na(ci) && verbose) {
-      insight::format_warning("Confidence intervals are not yet supported for `by_group = TRUE`.")
+      insight::format_warning(
+        "Confidence intervals are not yet supported for `by_group = TRUE`."
+      )
     }
 
     # null-model
@@ -147,7 +153,8 @@ r2_nakagawa <- function(model,
     group_names <- insight::find_random(model, split_nested = TRUE, flatten = TRUE)
 
     # compute r2 by level
-    r2_random <- 1 - (vars$var.intercept[group_names] / vars_null$var.intercept[group_names])
+    r2_random <- 1 -
+      (vars$var.intercept[group_names] / vars_null$var.intercept[group_names])
     r2_fixed <- 1 - (vars$var.residual / vars_null$var.residual)
 
     out <- data.frame(
@@ -162,13 +169,18 @@ r2_nakagawa <- function(model,
     if (insight::is_empty_object(vars$var.random) || is.na(vars$var.random)) {
       if (verbose) {
         # if no random effect variance, return simple R2
-        insight::print_color("Random effect variances not available. Returned R2 does not account for random effects.\n", "red") # nolint
+        insight::print_color(
+          "Random effect variances not available. Returned R2 does not account for random effects.\n",
+          "red"
+        ) # nolint
       }
       r2_marginal <- vars$var.fixed / (vars$var.fixed + vars$var.residual)
       r2_conditional <- NA
     } else {
-      r2_marginal <- vars$var.fixed / (vars$var.fixed + vars$var.random + vars$var.residual)
-      r2_conditional <- (vars$var.fixed + vars$var.random) / (vars$var.fixed + vars$var.random + vars$var.residual)
+      r2_marginal <- vars$var.fixed /
+        (vars$var.fixed + vars$var.random + vars$var.residual)
+      r2_conditional <- (vars$var.fixed + vars$var.random) /
+        (vars$var.fixed + vars$var.random + vars$var.residual)
     }
 
     names(r2_conditional) <- "Conditional R2"
@@ -266,10 +278,20 @@ print.r2_nakagawa <- function(x, digits = 3, ...) {
 
   # add CI
   if (length(x$R2_conditional) == 3) {
-    out[1] <- .add_r2_ci_to_print(out[1], x$R2_conditional[2], x$R2_conditional[3], digits = digits)
+    out[1] <- .add_r2_ci_to_print(
+      out[1],
+      x$R2_conditional[2],
+      x$R2_conditional[3],
+      digits = digits
+    )
   }
   if (length(x$R2_marginal) == 3) {
-    out[2] <- .add_r2_ci_to_print(out[2], x$R2_marginal[2], x$R2_marginal[3], digits = digits)
+    out[2] <- .add_r2_ci_to_print(
+      out[2],
+      x$R2_marginal[2],
+      x$R2_marginal[3],
+      digits = digits
+    )
   }
 
   # separate lines for multiple R2
@@ -301,7 +323,8 @@ print.r2_nakagawa <- function(x, digits = 3, ...) {
   } else {
     c(
       vars$var.fixed / (vars$var.fixed + vars$var.random + vars$var.residual),
-      (vars$var.fixed + vars$var.random) / (vars$var.fixed + vars$var.random + vars$var.residual)
+      (vars$var.fixed + vars$var.random) /
+        (vars$var.fixed + vars$var.random + vars$var.residual)
     )
   }
 }
@@ -322,14 +345,17 @@ print.r2_nakagawa <- function(x, digits = 3, ...) {
   } else {
     c(
       vars$var.fixed / (vars$var.fixed + vars$var.random + vars$var.residual),
-      (vars$var.fixed + vars$var.random) / (vars$var.fixed + vars$var.random + vars$var.residual)
+      (vars$var.fixed + vars$var.random) /
+        (vars$var.fixed + vars$var.random + vars$var.residual)
     )
   }
 }
 
 # main bootstrap function
 .bootstrap_r2_nakagawa <- function(model, iterations, tolerance, ci_method = NULL, ...) {
-  if (inherits(model, c("merMod", "lmerMod", "glmmTMB")) && !identical(ci_method, "boot")) {
+  if (
+    inherits(model, c("merMod", "lmerMod", "glmmTMB")) && !identical(ci_method, "boot")
+  ) {
     result <- .do_lme4_bootmer(
       model,
       .boot_r2_fun_lme4,
